***This STATA code replicates the figures and tables in "Islamic Constitutions and Democracy" by Gouda and Hanafy, published in Political Research Quarterly. 
***The code was run using STATA version 13. 


*Open the GoudaHanafy_PRQ_Replication.dta file:
use "GoudaHanafy_PRQ_Replication.dta"


*** Table 1 ***
quietly regress democracy  source log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so  y1991-y2014 region2-region5, vce(cluster ccode)
gen sampleDemoc=1 if e(sample)==1
eststo: estpost summarize democracy  polity2 SVMDI source supreme logdistance arabconquest log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so  muslim_share muslim_majority if sampleDemoc==1
eststo: estpost summarize democracy  polity2 SVMDI source supreme logdistance arabconquest log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so  muslim_share muslim_majority if supreme>0&sampleDemoc==1
eststo: estpost summarize democracy  polity2 SVMDI source supreme logdistance arabconquest log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so  muslim_share muslim_majority if supreme==0&sampleDemoc==1
esttab using "descriptives.rtf", cells("mean(fmt(2)) sd(fmt(2)) min(fmt(2)) max(fmt(2))") nonumber title("Table 1: Descriptive statistics") mtitle("Full sample" "Treated sample" "Control sample") varlabels(democracy "Democracy" polity2 "Polity2" source "Source" supreme "Supremacy" logdistance "Distance" arabconquest "Conquest" log_oilgaspc "Natural resources" log_gdppc "GDP per capita" KOFGI "Globalization" legor_uk "British legal origin" legor_fr "French legal origin" legor_so "Socialist legal origin" muslim_share "Share Muslim" muslim_majority "Majority Muslim") 



*** Table 2 ***
estimates clear
eststo: regress democracy  source log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so  y1991-y2014 region2-region5, vce(cluster ccode)
eststo: regress democracy  source log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so  muslim_share y1991-y2014 region2-region5, vce(cluster ccode)
eststo: regress democracy  source log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so  muslim_majority y1991-y2014 region2-region5, vce(cluster ccode)
eststo: regress democracy  supreme log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so  y1991-y2014 region2-region5, vce(cluster ccode)
eststo: regress democracy  supreme log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so  muslim_share y1991-y2014 region2-region5, vce(cluster ccode)
eststo: regress democracy  supreme log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so  muslim_majority y1991-y2014 region2-region5, vce(cluster ccode)
esttab using "results.rtf", cells(b(star fmt(3)) se(par fmt(3))) stats(N N_clust, fmt(%9.0gc %9.0g) labels(Observations Countries)) collabels(none) varlabels(_cons Constant source "Source" supreme "Supremacy" log_oilgaspc "Natural resources" log_gdppc "GDP per capita" KOFGI "Globalization" legor_uk "British legal origin" legor_fr "French legal origin" legor_so "Socialist legal origin" muslim_share "Share Muslim" muslim_majority "Majority Muslim") drop(y* region*) title("Table 2: Effect of Islamic constitutions on democracy, OLS") nomtitles star(* 0.05 ** 0.01 *** 0.001) replace note("*: 0.05 , **: 0.01 , ***: 0.001") varwidth(25) modelwidth(8)


*** Table 3 ***
estimates clear
eststo: ivreg2 democracy  (source = logdistance arabconquest) log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so  y1991-y2014 region2-region5, cluster (ccode)
eststo: ivreg2 democracy  (source = logdistance arabconquest) log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so  muslim_share y1991-y2014 region2-region5, cluster (ccode)
eststo: ivreg2 democracy  (source = logdistance arabconquest) log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so muslim_majority y1991-y2014 region2-region5, cluster (ccode)
eststo: ivreg2 democracy  (supreme = logdistance arabconquest) log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so  y1991-y2014 region2-region5, cluster (ccode)
eststo: ivreg2 democracy  (supreme = logdistance arabconquest) log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so  muslim_share y1991-y2014 region2-region5, cluster (ccode)
eststo: ivreg2 democracy  (supreme = logdistance arabconquest) log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so muslim_majority y1991-y2014 region2-region5, cluster (ccode)
esttab using "results.rtf", cells(b(star fmt(3)) se(par fmt(3))) stats(idstat idp rkf j jp N N_clust, fmt(%9.2f %9.3f %9.2f  %9.2f %9.3f %9.0gc %9.0g) labels(Underidentification " p-value" "Kleibergen-Paap F" "Hansen J" " p-value" Observations Countries)) collabels(none) varlabels(_cons Constant source "Source" supreme "Supremacy" log_oilgaspc "Natural resources" log_gdppc "GDP per capita" KOFGI "Globalization" legor_uk "British legal origin" legor_fr "French legal origin" legor_so "Socialist legal origin" muslim_share "Share Muslim" muslim_majority "Majority Muslim") drop(y* region*) title("Table 3: Effect of Islamic constitutions on democracy, 2SLS") nomtitles star(* 0.05 ** 0.01 *** 0.001) append note("*: 0.05 , **: 0.01 , ***: 0.001") varwidth(25) modelwidth(8)



*** Table A.2 ***
estimates clear
 probit democracy  source log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_so y1991-y2014 region2-region5, vce(cluster ccode)
eststo m1: margins, dydx (*)  post
probit democracy  source log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_so muslim_share y1991-y2014 region2-region5, vce(cluster ccode)
eststo m2: margins, dydx (*)  post
probit democracy  source log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_so muslim_majority y1991-y2014 region2-region5, vce(cluster ccode)
eststo m3: margins, dydx (*)  post
probit democracy  supreme log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_so y1991-y2014 region2-region5, vce(cluster ccode)
eststo m4: margins, dydx (*)  post
probit democracy  supreme log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_so muslim_share y1991-y2014 region2-region5, vce(cluster ccode)
eststo m5: margins, dydx (*)  post
probit democracy  supreme log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_so muslim_majority y1991-y2014 region2-region5, vce(cluster ccode)
eststo m6: margins, dydx (*)  post
esttab using "results.rtf", cells(b(star fmt(3)) se(par fmt(3))) stats(N N_clust, fmt(%9.0gc %9.0g) labels(Observations Countries)) collabels(none) varlabels(_cons Constant source "Source" supreme "Supremacy" log_oilgaspc "Natural resources" log_gdppc "GDP per capita" KOFGI "Globalization" legor_uk "British legal origin" legor_fr "French legal origin" legor_so "Socialist legal origin" muslim_share "Share Muslim" muslim_majority "Majority Muslim") drop(y* region*) title("Table A.2: Effect of Islamic constitutions on democracy, Probit, Marginal Effects") nomtitles star(* 0.05 ** 0.01 *** 0.001) replace note("*: 0.05 , **: 0.01 , ***: 0.001") varwidth(25) modelwidth(8)


*** Table A.3 ***
estimates clear
eststo: regress source logdistance arabconquest log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so y1991-y2014 region2-region5, vce(cluster ccode)
test logdistance arabconquest 
eststo: regress source logdistance arabconquest log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so muslim_share y1991-y2014 region2-region5, vce(cluster ccode)
test logdistance arabconquest
eststo: regress source logdistance arabconquest  log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so muslim_majority y1991-y2014 region2-region5, vce(cluster ccode)
test logdistance arabconquest
eststo: regress supreme logdistance arabconquest log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so y1991-y2014 region2-region5, vce(cluster ccode)
test logdistance arabconquest
eststo: regress supreme logdistance arabconquest log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so muslim_share y1991-y2014 region2-region5, vce(cluster ccode)
test logdistance arabconquest
eststo: regress supreme logdistance arabconquest  log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so muslim_majority y1991-y2014 region2-region5, vce(cluster ccode)
test logdistance arabconquest
esttab using "results.rtf", cells(b(star fmt(3)) se(par fmt(3))) stats(N N_clust, fmt(%9.0gc %9.0g) labels(Observations Countries)) collabels(none) varlabels(_cons Constant logdistance "Distance (IV)" arabconquest "Conquest (IV)" log_oilgaspc "Natural resources" log_gdppc "GDP per capita" KOFGI "Globalization" legor_uk "British legal origin" legor_fr "French legal origin" legor_so "Socialist legal origin" muslim_share "Share Muslim" muslim_majority "Majority Muslim")  drop(y* region*) title("Table A.3: First Stage") nomtitles star(* 0.05 ** 0.01 *** 0.001) replace note("*: 0.05 , **: 0.01 , ***: 0.001") varwidth(25) modelwidth(8)


*** Table A.4 ***
estimates clear
eststo: regress polity2  source log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so  y1991-y2014 region2-region5, vce(cluster ccode)
eststo: regress polity2  source log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so  muslim_share y1991-y2014 region2-region5, vce(cluster ccode)
eststo: regress polity2  source log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so  muslim_majority y1991-y2014 region2-region5, vce(cluster ccode)
eststo: regress SVMDI  source log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so  y1991-y2014 region2-region5, vce(cluster ccode)
eststo: regress SVMDI  source log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so  muslim_share y1991-y2014 region2-region5, vce(cluster ccode)
eststo: regress SVMDI  source log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so  muslim_majority y1991-y2014 region2-region5, vce(cluster ccode)
esttab using "results.rtf", cells(b(star fmt(3)) se(par fmt(3))) stats(N N_clust, fmt(%9.0gc %9.0g) labels(Observations Countries)) collabels(none) varlabels(_cons Constant source "Source" supreme "Supremacy" log_oilgaspc "Natural resources" log_gdppc "GDP per capita" KOFGI "Globalization" legor_uk "British legal origin" legor_fr "French legal origin" legor_so "Socialist legal origin" muslim_share "Share Muslim" muslim_majority "Majority Muslim") drop(y* region*) title("Table A.4: Alternative democracy measures as dependent variables, OLS") nomtitles star(* 0.05 ** 0.01 *** 0.001) replace note("*: 0.05 , **: 0.01 , ***: 0.001") varwidth(25) modelwidth(8)


*** Table A.5 ***
estimates clear
eststo: ivreg2 polity2  (source = logdistance arabconquest) log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so  y1991-y2014 region2-region5, cluster (ccode)
eststo: ivreg2 polity2  (source = logdistance arabconquest) log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so  muslim_share y1991-y2014 region2-region5, cluster (ccode)
eststo: ivreg2 polity2  (source = logdistance arabconquest) log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so muslim_majority y1991-y2014 region2-region5, cluster (ccode)
eststo: ivreg2 SVMDI  (source = logdistance arabconquest) log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so  y1991-y2014 region2-region5, cluster (ccode)
eststo: ivreg2 SVMDI  (source = logdistance arabconquest) log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so  muslim_share y1991-y2014 region2-region5, cluster (ccode)
eststo: ivreg2 SVMDI  (source = logdistance arabconquest) log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so muslim_majority y1991-y2014 region2-region5, cluster (ccode)
esttab using "results.rtf", cells(b(star fmt(3)) se(par fmt(3))) stats(idstat idp rkf j jp N N_clust, fmt(%9.2f %9.3f %9.2f  %9.2f %9.3f %9.0gc %9.0g) labels(Underidentification " p-value" "Kleibergen-Paap F" "Hansen J" " p-value" Observations Countries)) collabels(none) varlabels(_cons Constant source "Source" supreme "Supremacy" log_oilgaspc "Natural resources" log_gdppc "GDP per capita" KOFGI "Globalization" legor_uk "British legal origin" legor_fr "French legal origin" legor_so "Socialist legal origin" muslim_share "Share Muslim" muslim_majority "Majority Muslim") drop(y* region*) title("Table A.5: Alternative democracy measures as dependent variables, 2SLS") nomtitles star(* 0.05 ** 0.01 *** 0.001) append note("*: 0.05 , **: 0.01 , ***: 0.001") varwidth(25) modelwidth(8)


*** Table A.6 ***
estimates clear
eststo: regress democracy  source log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so  freerel y1991-y2014 region2-region5, vce(cluster ccode)
eststo: regress democracy  source log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so freerel muslim_share y1991-y2014 region2-region5, vce(cluster ccode)
eststo: regress democracy  source log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so freerel muslim_majority y1991-y2014 region2-region5, vce(cluster ccode)
eststo: regress democracy  supreme log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so freerel y1991-y2014 region2-region5, vce(cluster ccode)
eststo: regress democracy  supreme log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so freerel muslim_share y1991-y2014 region2-region5, vce(cluster ccode)
eststo: regress democracy  supreme log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so freerel muslim_majority y1991-y2014 region2-region5, vce(cluster ccode)
esttab using "results.rtf", cells(b(star fmt(3)) se(par fmt(3))) stats(N N_clust, fmt(%9.0gc %9.0g) labels(Observations Countries)) collabels(none) varlabels(_cons Constant source "Source" supreme "Supremacy" log_oilgaspc "Natural resources" log_gdppc "GDP per capita" KOFGI "Globalization" legor_uk "British legal origin" legor_fr "French legal origin" legor_so "Socialist legal origin" freerel "Freedom of religion" muslim_share "Share Muslim" muslim_majority "Majority Muslim") drop(y* region*) title("Table A.6: Additional control variable on freedom of religion in constitutions, OLS") nomtitles star(* 0.05 ** 0.01 *** 0.001) replace note("*: 0.05 , **: 0.01 , ***: 0.001") varwidth(25) modelwidth(8)


*** Table A.7 ***
estimates clear
eststo: regress democracy  source log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so spatialdemocracy y1991-y2014 region2-region5, vce(cluster ccode)
eststo: regress democracy  source log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so spatialdemocracy muslim_share y1991-y2014 region2-region5, vce(cluster ccode)
eststo: regress democracy  source log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so spatialdemocracy muslim_majority y1991-y2014 region2-region5, vce(cluster ccode)
eststo: regress democracy  source log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so  ODA_log y1991-y2014 region2-region5, vce(cluster ccode)
eststo: regress democracy  source log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so ODA_log muslim_share y1991-y2014 region2-region5, vce(cluster ccode)
eststo: regress democracy  source log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so ODA_log muslim_majority y1991-y2014 region2-region5, vce(cluster ccode)
esttab using "results.rtf", cells(b(star fmt(3)) se(par fmt(3))) stats(N N_clust, fmt(%9.0gc %9.0g) labels(Observations Countries)) collabels(none) varlabels(_cons Constant source "Source" supreme "Supremacy" log_oilgaspc "Natural resources" log_gdppc "GDP per capita" KOFGI "Globalization" legor_uk "British legal origin" legor_fr "French legal origin" legor_so "Socialist legal origin" ODA_log "ODA" muslim_share "Share Muslim" muslim_majority "Majority Muslim")  drop(y* region*)  title("Table A.7: Additional control variables on external effects, OLS") nomtitles star(* 0.05 ** 0.01 *** 0.001) replace note("*: 0.05 , **: 0.01 , ***: 0.001") varwidth(25) modelwidth(8)

 
*** Table A.8 ***
estimates clear
eststo: regress democracy  source log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so schooling y1991-y2014 region2-region5, vce(cluster ccode)
eststo: regress democracy  source log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so schooling muslim_share y1991-y2014 region2-region5, vce(cluster ccode)
eststo: regress democracy  source log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so schooling muslim_majority y1991-y2014 region2-region5, vce(cluster ccode)
eststo: regress democracy  source log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so gini y1991-y2014 region2-region5, vce(cluster ccode)
eststo: regress democracy  source log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so gini muslim_share y1991-y2014 region2-region5, vce(cluster ccode)
eststo: regress democracy  source log_oilgaspc log_gdppc  KOFGI presidential legor_uk legor_fr legor_so gini muslim_majority y1991-y2014 region2-region5, vce(cluster ccode)
esttab using "results.rtf", cells(b(star fmt(3)) se(par fmt(3))) stats(N N_clust, fmt(%9.0gc %9.0g) labels(Observations Countries)) collabels(none) varlabels(_cons Constant source "Source" supreme "Supremacy" log_oilgaspc "Natural resources" log_gdppc "GDP per capita" KOFGI "Globalization" legor_uk "British legal origin" legor_fr "French legal origin" legor_so "Socialist legal origin" schooling "Education" gini "Inequality" muslim_share "Share Muslim" muslim_majority "Majority Muslim")  drop(y* region*)  title("Table A.8: Additional control variables on education and inequality, OLS") nomtitles star(* 0.05 ** 0.01 *** 0.001) replace note("*: 0.05 , **: 0.01 , ***: 0.001") varwidth(25) modelwidth(8)





